---
title: West African Ebola Outbreak
authors: "Ashley Anderson"
date: "July 2018"
dataset: "https://nextstrain.org/ebola"
---
# [Summary](https://nextstrain.org/ebola)

In December 2013, a devastating outbreak of Ebolavirus began in Western Africa, specifically Sierra Leone, Liberia, and Guinea. Approximately 28,000 cases of Ebolavirus were observed during this time period (Havard). The outbreak presisted for approximately 3 years causing a significant loss of life and disruption to the economy of the respective divisions. Many individuals have been dedicated to better understanding this virus in hopes of preventing future epidemics.

<figure class="image"><img src="https://phil.cdc.gov//PHIL_Images/10816/10816_lores.jpg" alt="TEM image of Ebola virus virion"><figcaption>Transmission electron microscope image of the Ebola virus virion. Source: CDC/Cynthia Goldsmith.</figcaption>

Ebolavirus is transmitted through bodily fluids by direct contact with someone who is infected or has died. According to the Center for Disease Control, Ebolavirus is animal borne, meaning it is carried by animals and transmitted to humans, and the bats are likely the original source (CDC).

<figure class="image"><img src="https://d2ufo47lrtsv5s.cloudfront.net/content/sci/335/6068/530/F2.medium.gif?width=800&height=600&carousel=1" alt="3D model of Ebola virus"><figcaption>3D Rendering of the Ebola virus. Source: Science/Visual-Science.</figcaption>


To combat Ebolavirus, multiple vaccine candidates have been developed; however, they largely remain in trial and only one, rVSV-ZEBOV Ebola vaccine, is approved for "compassionate use" during outbreaks (NIH, WHO). This vaccine is only given to high-risk persons, or persons who have come in contact with someone known to be infected with Ebola (WHO).


Most recently, in May of 2018, a smaller but also devestating outbreak began in the Democratic Republic of Congo. The outbreak was limited to 50 cases with 27 deaths (Harvard). While the outbreak has not yet been considered over, Tedros Adhanom Ghebreyesus, the Directory General of the World Health Organization, recently tweeted that, provided no additional cases are reported, July 24 will mark the end of the outbreak.

<blockquote class="twitter-tweet" data-lang="en"><p lang="en" dir="ltr">If no new <a href="https://twitter.com/hashtag/Ebola?src=hash&mp;ref_src=twsrc%5Etfw">#Ebola</a> cases are confirmed in <a href="https://twitter.com/hashtag/DRC?src=hash&amp;ref_src=twsrc%5Etfw">#DRC</a>, 24 July will mark the end of the outbreak, with an official <a href="https://twitter.com/MinSanteRDC?ref_src=twsrc%5Etfw">@MinSanteRDC</a> announcement on 25 July. Active surveillance is still ongoing, and will continue after the end of the outbreak. <a href="https://t.co/qnoyvMmbfn">pic.twitter.com/qnoyvMmbfn</a></p>&mdash; Tedros Adhanom Ghebreyesus (@DrTedros) <a href="https://twitter.com/DrTedros/status/1019530779930648577?ref_src=twsrc%5Etfw">July 18, 2018</a></blockquote>
<script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

This narrative will step through pieces of the 2013-2016 West Africa Ebola outbreak to help garner a better understanding of the evolution of the virus that could be a factor in its presistance within the population.


# [Ebola genome](https://nextstrain.org/ebola?d=entropy&p=full)

![Ebola Genome](https://viralzone.expasy.org/resources/Filovirus_genome.png)

Ebola is a virus that is made up of a single strand of RNA.

On the right panel is the genome of the Ebola virus.

* How many genes are in the Ebola genome?
* What proteins are found in its genome? Use your worksheet from yesterday to help you.


# [Location](https://nextstrain.org/ebola?d=map&p=full)

Using the map, answer the following questions:
* Where does it appear that Ebola emerged from?
* From a geographic point of view, where does it appear to have expanded most rapidly?
* In which regions do the number of cases appear to most rapidly increase?


# [Phylogenetic Tree](https://nextstrain.org/ebola?d=tree&p=full)

Using your answers to the previous questions, examine the phlyogenetic tree and determine if you were correct. Record your answers in your notebook.


# [Mutations](https://nextstrain.org/ebola?d=tree,entropy&p=full)

Read through the **ALL the directions** before completing them.

* Click "show controls" on the top (this box will now switch to the controls you saw earlier).
* Scroll until you see "Branch Labels"
* Click the drop-down menu and select "aa"; this stands for amino acid
* The phylogenetic tree should now labels suchs as "A82V"
* Scroll up to the top and click "show narrative" to return

You have now added amino acid labels to the tree. These labels represent amino acid mutations from the ancestral sequence to the derived (new) are in the format of "A82V", where:
* The first letter (A) represents the amino acid found in the ancestral sequence
* The number (82) represents the position in the amino acid sequence
* The last letter (V) represents derived amino acid (aka the new amino acid that appears at that position)

Using the tree, find **5** mutations and determine the following:
* What amino acid was in the ancestral sequence?
* What amino acid appears in the mutated sequence?
* What is the position of the amino acid?

Use the following chart to translate the letter amino acid representation to the full name:
![Amino Acid Chart](http://www.compoundchem.com/wp-content/uploads/2014/09/20-Common-Amino-Acids-v3.png)

Now, let's examine some amino acid mutations associated with the outbreak.


# [Mutation 1](https://nextstrain.org/ebola?d=tree,entropy&p=full&c=gt-L_759)

The tree is now colored according to the genotype (specific amino acid) on the L protein at position 759.

Answer the following questions to guide your analysis:
* What is the function of the L protein?
* What is the specific amino acid mutation?
* Why might a mutation in this amino acid make Ebola more virulent?



# [Mutation 2](https://nextstrain.org/ebola?d=tree,entropy&p=full&c=gt-GP_82)

The tree is now colored according to the genotype (specific amino acid) on the GP protein at position 82.

Answer the following questions to guide your analysis:
* What is the function of the GP protein?
* What is the specific amino acid mutation?
* Why might a mutation in this amino acid make Ebola more virulent?



# [Other Mutations](https://nextstrain.org/ebola?d=tree&p=full)

_TO DO_
The branches of the tree have been labeled wtih the amino acid mutations that occur within the subsequent clade. Your task is to  examine the branches and see what other amino acid mutations are associated with the outbreak. You can zoom in to any clade by clicking on the branch you are interested in.

Answer the following questions as you go:
* What other mutations can you find?
* What proteins are these mutations associated with?
* Do these mutations appear to make the virus more or less fit? How do you know?


# [Citations](https://nextstrain.org/ebola?d=map&p=full)

Hadfield, J., C. Megill, S. M. Bell, J. Huddleston, B. Potter, C. Callender, P. Sagulenko, T. Bedford, and R. A. Neher. [Nextstrain: real-time tracking of pathogen evolution](https://doi.org/10.1093/bioinformatics/bty407), Bioinformatics 2018

Bedford, T. & Malik, H. S. (2016) [Did a Single Amino Acid Change Make Ebola Virus More Virulent?](https://www.sciencedirect.com/science/article/pii/S0092867416314520?via%3Dihub), Cell, 167(4), pp. 892-894

[Ebola Vaccines](https://www.niaid.nih.gov/diseases-conditions/ebola-vaccines) (2018). National Institute of Allergy and Infectious Diseases. (accessed 7.19.18).

[Ebola virus disease – Democratic Republic of the Congo](http://www.who.int/csr/don/23-may-2018-ebola-drc/en/) (2018). [WWW Document]. World Health Organization. (accessed 7.19.18).

Srikrishna, R.S.D.D., (2018). [An Ebola Outbreak Has Just Been Stopped. Here's What It Tells Us About Containing Epidemics.](https://hbr.org/2018/07/an-ebola-outbreak-has-just-been-stopped-heres-what-it-tells-us-about-containing-epidemics). Harvard Business Review. (accessed 7.19.18).




<!-- STYLES TO APPLY -->
<style>
  figcaption {
      font-style: italic;
      font-size: 12.5px;
      margin-bottom: 15px;
  }
</style>
